"""Tests for sktime annotators."""

__author__ = ["miraep8", "fkiraly", "klam-data", "pyyim", "mgorlin"]
__all__ = []

import numpy as np
import pandas as pd

from sktime.tests.test_all_estimators import BaseFixtureGenerator, QuickTester
from sktime.utils._testing.annotation import make_annotation_problem
from sktime.utils.validation.annotation import check_learning_type, check_task


class AnnotatorsFixtureGenerator(BaseFixtureGenerator):
    """Fixture generator for time series annotator (outlier, change point, etc) tests.

    Fixtures parameterized
    ----------------------
    estimator_class: estimator inheriting from BaseObject
        ranges over estimator classes not excluded by EXCLUDE_ESTIMATORS, EXCLUDED_TESTS
    estimator_instance: instance of estimator inheriting from BaseObject
        ranges over estimator classes not excluded by EXCLUDE_ESTIMATORS, EXCLUDED_TESTS
        instances are generated by create_test_instance class method
    scenario: instance of TestScenario
        ranges over all scenarios returned by retrieve_scenarios
    """

    # note: this should be separate from TestAllAnnotators
    #   additional fixtures, parameters, etc should be added here
    #   TestAllAnnotators should contain the tests only

    estimator_type_filter = "series-annotator"


class TestAllAnnotators(AnnotatorsFixtureGenerator, QuickTester):
    """Module level tests for all sktime annotators."""

    def test_output_type(self, estimator_instance):
        """Test annotator output type."""
        estimator = estimator_instance

        arg = make_annotation_problem(
            n_timepoints=50, estimator_type=estimator.get_tag("distribution_type")
        )
        estimator.fit(arg)
        arg = make_annotation_problem(
            n_timepoints=10, estimator_type=estimator.get_tag("distribution_type")
        )
        y_pred = estimator.predict(arg)
        assert isinstance(y_pred, (pd.Series, np.ndarray))

    def test_annotator_tags(self, estimator_class):
        """Check the learning_type and task tags are valid."""
        check_task(estimator_class.get_class_tag("task"))
        check_learning_type(estimator_class.get_class_tag("learning_type"))
